# Hanifx PyPI Uploader (v13.0.0)

A simple PyPI uploader module written in Python that does NOT require `twine`.

## Features

- Upload packages directly to PyPI using `requests`
- Supports `.whl` and `.tar.gz` files in `dist/` folder by default
- Simple CLI with token authentication
- Upload logs to `upload.log`

## Installation

```bash
pip install requests
pip install .
python setup.py sdist bdist_wheel


hanifx-upload --token YOUR_PYPI_API_TOKEN --files dist/yourpkg-1.0.0.tar.gz


hanifx-upload --token YOUR_PYPI_API_TOKEN
